<?php 

/**
 * Social Icons widget
 *
 * @package Parallax Blog
 */

add_action('widgets_init', 'register_social_icon_widget');

function register_social_icon_widget(){
    register_widget( 'Parallax_Blog_Social_Icons' );
}

class Parallax_Blog_Social_Icons extends WP_Widget {

	 /**
     * Register widget with WordPress.
     */
    public function __construct() {
        parent::__construct(
            'parallax_blog_social_icons',
            esc_html__('Parallax Blog: Social Icons','parallax-blog'),
            array(
                'description'   => esc_html__( 'A widget which shows social icons in your profile', 'parallax-blog' )
            )
        );
    }

    /**
     * Helper function that holds widget fields
     * Array is used in update and form functions
     */
    private function widget_fields() {
        $fields = array(
            // Title
            'widget_title' => array(
                'parallax_blog_widgets_name' => 'widget_title',
                'parallax_blog_widgets_title' => esc_html__('Title', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            // Other fields
            'twitter' => array(
                'parallax_blog_widgets_name' => 'twitter',
                'parallax_blog_widgets_title' => esc_html__('Twitter', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'facebook' => array(
                'parallax_blog_widgets_name' => 'facebook',
                'parallax_blog_widgets_title' => esc_html__('Facebook', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'linkedin' => array(
                'parallax_blog_widgets_name' => 'linkedin',
                'parallax_blog_widgets_title' => esc_html__('LinkedIn', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'gplus' => array(
                'parallax_blog_widgets_name' => 'google-plus',
                'parallax_blog_widgets_title' => esc_html__('Google+', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'pinterest' => array(
                'parallax_blog_widgets_name' => 'pinterest',
                'parallax_blog_widgets_title' => esc_html__('Pinterest', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'youtube' => array(
                'parallax_blog_widgets_name' => 'youtube',
                'parallax_blog_widgets_title' => esc_html__('YouTube', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'vimeo' => array(
                'parallax_blog_widgets_name' => 'vimeo',
                'parallax_blog_widgets_title' => esc_html__('Vimeo', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'flickr' => array(
                'parallax_blog_widgets_name' => 'flickr',
                'parallax_blog_widgets_title' => esc_html__('Flickr', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'dribbble' => array(
                'parallax_blog_widgets_name' => 'dribbble',
                'parallax_blog_widgets_title' => esc_html__('Dribbble', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'stumbleupon' => array(
                'parallax_blog_widgets_name' => 'stumbleupon',
                'parallax_blog_widgets_title' => esc_html__('Stumbleupon', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'tumblr' => array(
                'parallax_blog_widgets_name' => 'tumblr',
                'parallax_blog_widgets_title' => esc_html__('Tumblr', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'instagram' => array(
                'parallax_blog_widgets_name' => 'instagram',
                'parallax_blog_widgets_title' => esc_html__('Instagram', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'lastfm' => array(
                'parallax_blog_widgets_name' => 'skype',
                'parallax_blog_widgets_title' => esc_html__('Skype', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
            'soundcloud' => array(
                'parallax_blog_widgets_name' => 'soundcloud',
                'parallax_blog_widgets_title' => esc_html__('SoundCloud', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text'
            ),
        );

        return $fields;
    }


    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget($args, $instance) {
        extract($args);

        $widget_title = empty($instance['widget_title']) ? '' : $instance['widget_title'];
        //$parallax_blog_widgets_title = isset($instance['parallax_blog_widgets_title']) ? $instance['parallax_blog_widgets_title'] : '';
        
        echo $before_widget;

        // Show title
        if (isset($widget_title)) {
            echo $before_title . $widget_title . $after_title;
        }

        echo '<ul class="clearfix widget-social-icons">';
        // Loop through fields
        $widget_fields = $this->widget_fields();
        //var_dump($widget_fields);
        unset($widget_fields['widget_title']);
        foreach ($widget_fields as $widget_field) {
            // Make array elements available as variables
            extract($widget_field);
            // Check if field has value and skip title field
            unset($parallax_blog_widgets_field_value);
            if (isset($instance[$parallax_blog_widgets_name]) && 'widget_title' != $parallax_blog_widgets_name) {
                $parallax_blog_widgets_field_value = esc_attr($instance[$parallax_blog_widgets_name]);
                if ('' != $parallax_blog_widgets_field_value) {
                    ?>
                    <li>
                        <a href="<?php echo $parallax_blog_widgets_field_value; ?>" target="_blank">
                            <i class="fa fa-<?php echo $parallax_blog_widgets_name; ?>"></i>
                            <!-- <span class="icon-tooltip">
                                <?php //echo esc_attr($parallax_blog_widgets_title);?>
                            </span> -->
                        </a>
                    </li>
                    <?php
                }
            }
        }
        echo '</ul>';

        echo $after_widget;
    }

     /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param	array	$new_instance	Values just sent to be saved.
     * @param	array	$old_instance	Previously saved values from database.
     *
     * @uses	parallax_blog_widgets_show_widget_field()		defined in widget-fields.php
     *
     * @return	array Updated safe values to be saved.
     */
    public function update($new_instance, $old_instance) {
        $instance = $old_instance;

        $widget_fields = $this->widget_fields();

        // Loop through fields
        foreach ($widget_fields as $widget_field) {
            extract($widget_field);

            // Use helper function to get updated field values
            $instance[$parallax_blog_widgets_name] = parallax_blog_widgets_updated_field_value($widget_field, $new_instance[$parallax_blog_widgets_name]);
        }

        return $instance;
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     *
     * @uses	parallax_blog_widgets_show_widget_field()		defined in widget-fields.php
     */
    public function form($instance) {
        $widget_fields = $this->widget_fields();

        // Loop through fields
        foreach ($widget_fields as $widget_field) {

            // Make array elements available as variables
            extract($widget_field);
            $parallax_blog_widgets_field_value = isset($instance[$parallax_blog_widgets_name]) ? esc_attr($instance[$parallax_blog_widgets_name]) : '';
            parallax_blog_widgets_show_widget_field($this, $widget_field, $parallax_blog_widgets_field_value);
        }
    }

}
